################
Definitions
################

This section introduces the core concepts behind the DDM
and defines terms used throughout the Researcher Manual.

Data Donation Process
*********************

A prototypical data donation as implemented in the DDM consists of 4 steps.
These steps can be individually defined within a data donation project.
Participants will access a data donation project through a link provided by the
researchers and go through the following steps in their browser:


**1. Welcome/Briefing Page**

First, participants are presented with a welcome/briefing page.
On this page, researchers...

- describe their project.
- disclose their data security policies.
- inform about potential risks of a data donation.
- etc.

Based on this information, participants should be able to make an
informed decision on whether they would like to continue with the data donation.


**2. Data Donation**

Next, participants are presented with the instructions on how to access the data
of interest. Along with the instructions, a data upload form is provided.
The user flow in this step looks as follows:

a. Participants read the instructions and download/find the relevant the on their PC.
b. Participants upload their data with the provided upload form.
c. The uploaded data is filtered and transformed according to the rules defined by the researcher (e.g., only certain fields are extracted).
d. The participant is presented with the filtered/transformed data which they will be donating to the researchers.
e. Based on *d*, the participant can decide whether to donate their data (i.e., submit their data to the reseacher's server) or to abort.

Steps *b* to *c* are all client-based and executed in the participant's browser.
No personal data is submitted until step *e*.


**3. Follow-Up Questionnaire (optional)**

If data were donated, participants are presented with a follow-up questionnaire
(this step is optional).
Researchers can define the questions to include references to data points from
the donated data.


**4. End/Debriefing Page**

Lastly, participants are presented with a debriefing page.


Perspectives
************

The data donation process can either be looked at from the researcher's or the
participant's perspective.

**Researchers** uses the DDM to collect data donations for their own research
projects. A researcher is the owner of a data donation project and responsible
for setting the project up. You can find more about how to set up a data donation
project :doc:`here <./researcher_interface>`.

**Participants** are citizens who are recruited by researchers to donate personal
data for a research project.
Find out more about how the data donation process as implemented in the DDM
looks from the participant's perspective :doc:`here <./participation_flow>`.
